//
//  View.swift
//  Sine
//
//  Created by Mark Meretzky on 7/13/16.
//  Copyright © 2016 Mark Meretzky. All rights reserved.
//

import UIKit;

class View: UIView {

	required init(coder aDecoder: NSCoder) {
		super.init(coder: aDecoder)!;
		backgroundColor = UIColor.whiteColor();
	}

    // Only override drawRect: if you perform custom drawing.
    // An empty implementation adversely affects performance during animation.

	override func drawRect(rect: CGRect) {
		// Drawing code
		//How many sine waves do we want to draw?
		let n: CGFloat = 2.5;
		assert(n > 0);
		
		//Each sine wave is 2 * pi wide, so n sine waves would have a total
		//width of 2 * pi * n.  Scale the graphic so that 2 * pi * n would
		//stretch across the width of the View.
		let pi: CGFloat = CGFloat(M_PI); //Convert Double to CGFloat.
		let scale: CGFloat = bounds.size.width / (2 * pi * n);

		//With this scaleFactor, how many points wide would one pixel be?
		let onePixel: CGFloat = (1/3) / scale; //assume 3 pixels per point

		let c: CGContextRef = UIGraphicsGetCurrentContext()!;
		
		//Place the origin at the center of view, with Y axis pointing up.
		let centerTransform: CGAffineTransform =
			CGAffineTransformMakeTranslation(bounds.size.width / 2,  bounds.size.height / 2);
		let uprightTransform: CGAffineTransform = CGAffineTransformMakeScale(scale, -scale);
		let transform: CGAffineTransform = CGAffineTransformConcat(uprightTransform, centerTransform);
		CGContextConcatCTM(c, transform);

		//Draw the axes in faint blue.
		CGContextBeginPath(c);
		CGContextSetLineWidth(c, 3 * onePixel);
		
		//X axis
		CGContextMoveToPoint(c, -bounds.size.width / 2, 0);
		CGContextAddLineToPoint(c, bounds.size.width / 2, 0);
		
		//Y axis
		CGContextMoveToPoint(c, 0, bounds.size.height / 2);
		CGContextAddLineToPoint(c, 0, -bounds.size.height / 2);
		
		CGContextSetRGBStrokeColor(c, 0, 0, 1, 0.5);
		CGContextStrokePath(c);
		
		//Draw the graph of the sine function in black.
		CGContextBeginPath(c);
		CGContextSetLineWidth(c, onePixel);

		var first: Bool = true;
		for x: CGFloat in (-n * pi).stride(through: n * pi, by: onePixel) {
			let y: CGFloat = sin(x);			//Punchline.
			
			if first {
				//first iteration of loop
				CGContextMoveToPoint(c, x, y);
				first = false;
			} else {
				CGContextAddLineToPoint(c, x, y);
			}
		}
		
		CGContextSetRGBStrokeColor(c, 0, 0, 0, 1);
		CGContextStrokePath(c);
	}

}
